package cn.iocoder.yudao.module.wealth.vo.payment;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotNull;
import java.util.Date;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY;
import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
 * 付款单 Base VO，提供给添加、修改、详细的子 VO 使用
 * 如果子 VO 存在差异的字段，请不要添加到这里，影响 Swagger 文档生成
 */
@Data
public class PaymentBaseVO {

    @ApiModelProperty(value = "付款单号")
    private String paymentNo;

    @ApiModelProperty(value = "部门Id")
    private Long departmentId;

    @ApiModelProperty(value = "部门名称")
    private String departmentName;

    @ApiModelProperty(value = "业务员")
    private Long salesmanId;

    @ApiModelProperty(value = "业务员名称", required = true)
    @NotNull(message = "业务员名称不能为空")
    private String salesmanName;

    @ApiModelProperty(value = "供应商id")
    private Long supplierId;

    @ApiModelProperty(value = "供应商名称")
    private String supplierName;

    @ApiModelProperty(value = "银行名称")
    private String supplierBank;

    @ApiModelProperty(value = "银行账号")
    private String supplierBankAccount;

    @ApiModelProperty(value = "银行账户名称")
    private String supplierBankAccountName;

    @ApiModelProperty(value = "申请日期")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    @JsonFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    private Date applicationAt;

    @ApiModelProperty(value = "最迟付款日")
    @JsonFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    private Date latestPayAt;

    @ApiModelProperty(value = "账单号")
    private String accountNumber;

    @ApiModelProperty(value = "发票状态（0未开票，1已开票）")
    private Integer invoiceStatus;

    @ApiModelProperty(value = "发票号")
    private String invoiceNumber;

    @ApiModelProperty(value = "付款单状态（1待审核，2已审核待核销，3审核驳回，4已核销）")
    private Integer state;

    @ApiModelProperty(value = "付款单添加人id")
    private Long paymentAddId;

    @ApiModelProperty(value = "付款单添加人名称")
    private String paymentAddBy;

    @ApiModelProperty(value = "审核人id")
    private Long reviewId;

    @ApiModelProperty(value = "审核人名称")
    private String reviewName;

    @ApiModelProperty(value = "核销人id")
    private Long writeOffId;

    @ApiModelProperty(value = "核销人名称")
    private String writeOffName;

    @ApiModelProperty(value = "审核日期")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date reviewAt;

    @ApiModelProperty(value = "核销日期")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date writeOffAt;

    @ApiModelProperty(value = "数据来源（pc端，mobile端）")
    private String source;

    @ApiModelProperty(value = "结算方式")
    private Integer settlementType;

}
